@@ -7,7 +7,7 @@ setup(
     version="1.0",  # package version
     ext_modules=[
         Extension(
-            "greet", ["greet{}.c".format(sys.version_info[0])]  # extension to package
-        )  # C code to compile to run as extension
+            "greet", ["greet{}.c".format(sys.version_info[0])],  # extension to package
+        ),  # C code to compile to run as extension
     ],
 )
